#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dependent-sum
version:              0.7.2.0
visibility:           public
id:                   dependent-sum-0.7.2.0-5KVStjcgoBTD7ZsXrC0AkO
key:                  dependent-sum-0.7.2.0-5KVStjcgoBTD7ZsXrC0AkO
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/dependent-sum
synopsis:             Dependent sum type
description:
    A dependent sum is a generalization of a
    particular way of thinking about the @Either@
    type.  @Either a b@ can be thought of as a
    2-tuple @(tag, value)@, where the value of the
    tag determines the type of the value.  In
    particular, either @tag = Left@ and @value :: a@
    or @tag = Right@ and @value :: b@.

    This package allows you to define your own
    dependent sum types by using your own \"tag\"
    types.

category:             Data, Dependent Types
abi:                  0dca43a29e96da982447ba2767950e43
exposed:              True
exposed-modules:
    Data.Dependent.Sum,
    Data.GADT.Compare from some-1.0.6-FIfk4cSSsvfCiGo0eDPgfg:Data.GADT.Compare,
    Data.GADT.Show from some-1.0.6-FIfk4cSSsvfCiGo0eDPgfg:Data.GADT.Show,
    Data.Some from some-1.0.6-FIfk4cSSsvfCiGo0eDPgfg:Data.Some

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dependent-sum-0.7.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dependent-sum-0.7.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dependent-sum-0.7.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dependent-sum
hs-libraries:         HSdependent-sum-0.7.2.0-5KVStjcgoBTD7ZsXrC0AkO
depends:
    base-4.18.2.1 constraints-extras-0.4.0.2-9FR5rBY4faXJMiGQhQNwST
    some-1.0.6-FIfk4cSSsvfCiGo0eDPgfg

haddock-interfaces:
    /usr/share/doc/haskell-dependent-sum/html/dependent-sum.haddock

haddock-html:         /usr/share/doc/haskell-dependent-sum/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

